@@ -15,15 +15,16 @@
     - [`GitSync.get_git_version`](libvcs.git.GitProject.get_git_version)
 """  # NOQA: E501
 
+from __future__ import annotations
+
 import dataclasses
 import logging
 import pathlib
 import re
-from typing import Any, Optional, Union
+import typing as t
 from urllib import parse as urlparse
 
 from libvcs import exc
-from libvcs._internal.types import StrPath
 from libvcs.cmd.git import Git
 from libvcs.sync.base import (
     BaseSync,
@@ -31,6 +32,9 @@ from libvcs.sync.base import (
     convert_pip_url as base_convert_pip_url,
 )
 
+if t.TYPE_CHECKING:
+    from libvcs._internal.types import StrPath
+
 logger = logging.getLogger(__name__)
 
 
@@ -69,8 +73,7 @@ class GitRemoteRefNotFound(exc.CommandError):
 
     def __init__(self, git_tag: str, ref_output: str, *args: object) -> None:
         return super().__init__(
-            f"Could not fetch remote in refs/remotes/{git_tag}:"
-            + f"Output: {ref_output}",
+            f"Could not fetch remote in refs/remotes/{git_tag}. Output: {ref_output}",
         )
 
 
@@ -84,22 +87,22 @@ class GitRemote:
 
 
 GitSyncRemoteDict = dict[str, GitRemote]
-GitRemotesArgs = Union[None, GitSyncRemoteDict, dict[str, str]]
+GitRemotesArgs = None | GitSyncRemoteDict | dict[str, str]
 
 
 @dataclasses.dataclass
 class GitStatus:
     """Git status information."""
 
-    branch_oid: Optional[str] = None
-    branch_head: Optional[str] = None
-    branch_upstream: Optional[str] = None
-    branch_ab: Optional[str] = None
-    branch_ahead: Optional[str] = None
-    branch_behind: Optional[str] = None
+    branch_oid: str | None = None
+    branch_head: str | None = None
+    branch_upstream: str | None = None
+    branch_ab: str | None = None
+    branch_ahead: str | None = None
+    branch_behind: str | None = None
 
     @classmethod
-    def from_stdout(cls, value: str) -> "GitStatus":
+    def from_stdout(cls, value: str) -> GitStatus:
         """Return ``git status -sb --porcelain=2`` extracted to a dict.
 
         Returns
@@ -201,7 +204,7 @@ class GitSync(BaseSync):
         url: str,
         path: StrPath,
         remotes: GitRemotesArgs = None,
-        **kwargs: Any,
+        **kwargs: t.Any,
     ) -> None:
         """Local git repository.
 
@@ -297,7 +300,7 @@ class GitSync(BaseSync):
         self.url = self.chomp_protocol(origin.fetch_url)
 
     @classmethod
-    def from_pip_url(cls, pip_url: str, **kwargs: Any) -> "GitSync":
+    def from_pip_url(cls, pip_url: str, **kwargs: t.Any) -> GitSync:
         """Clone a git repository from a pip-style URL."""
         url, rev = convert_pip_url(pip_url)
         return cls(url=url, rev=rev, **kwargs)
@@ -347,7 +350,7 @@ class GitSync(BaseSync):
                         overwrite=overwrite,
                     )
 
-    def obtain(self, *args: Any, **kwargs: Any) -> None:
+    def obtain(self, *args: t.Any, **kwargs: t.Any) -> None:
         """Retrieve the repository, clone if doesn't exist."""
         self.ensure_dir()
 
@@ -374,7 +377,12 @@ class GitSync(BaseSync):
 
         self.set_remotes(overwrite=True)
 
-    def update_repo(self, set_remotes: bool = False, *args: Any, **kwargs: Any) -> None:
+    def update_repo(
+        self,
+        set_remotes: bool = False,
+        *args: t.Any,
+        **kwargs: t.Any,
+    ) -> None:
         """Pull latest changes from git remote."""
         self.ensure_dir()
 
@@ -393,9 +401,9 @@ class GitSync(BaseSync):
             self.log.debug("No git revision set, defaulting to origin/master")
             symref = self.cmd.symbolic_ref(name="HEAD", short=True)
             git_tag = symref.rstrip() if symref else "origin/master"
-        self.log.debug(f"git_tag: {git_tag}")
+        self.log.debug("git_tag: %s", git_tag)
 
-        self.log.info(f"Updating to '{git_tag}'.")
+        self.log.info("Updating to '%s'.", git_tag)
 
         # Get head sha
         try:
@@ -408,14 +416,14 @@ class GitSync(BaseSync):
             self.log.exception("Failed to get the hash for HEAD")
             return
 
-        self.log.debug(f"head_sha: {head_sha}")
+        self.log.debug("head_sha: %s", head_sha)
 
         # If a remote ref is asked for, which can possibly move around,
         # we must always do a fetch and checkout.
         show_ref_output = self.cmd.show_ref(pattern=git_tag, check_returncode=False)
-        self.log.debug(f"show_ref_output: {show_ref_output}")
+        self.log.debug("show_ref_output: %s", show_ref_output)
         is_remote_ref = "remotes" in show_ref_output
-        self.log.debug(f"is_remote_ref: {is_remote_ref}")
+        self.log.debug("is_remote_ref: %s", is_remote_ref)
 
         # show-ref output is in the form "<sha> refs/remotes/<remote>/<tag>"
         # we must strip the remote from the tag.
@@ -433,8 +441,8 @@ class GitSync(BaseSync):
                 raise GitRemoteRefNotFound(git_tag=git_tag, ref_output=show_ref_output)
             git_remote_name = m.group("git_remote_name")
             git_tag = m.group("git_tag")
-        self.log.debug(f"git_remote_name: {git_remote_name}")
-        self.log.debug(f"git_tag: {git_tag}")
+        self.log.debug("git_remote_name: %s", git_remote_name)
+        self.log.debug("git_tag: %s", git_tag)
 
         # This will fail if the tag does not exist (it probably has not
         # been fetched yet).
@@ -448,7 +456,7 @@ class GitSync(BaseSync):
         except exc.CommandError as e:
             error_code = e.returncode if e.returncode is not None else 0
             tag_sha = ""
-        self.log.debug(f"tag_sha: {tag_sha}")
+        self.log.debug("tag_sha: %s", tag_sha)
 
         # Is the hash checkout out what we want?
         somethings_up = (error_code, is_remote_ref, tag_sha != head_sha)
@@ -459,7 +467,7 @@ class GitSync(BaseSync):
         try:
             process = self.cmd.fetch(log_in_real_time=True, check_returncode=True)
         except exc.CommandError:
-            self.log.exception(f"Failed to fetch repository '{url}'")
+            self.log.exception("Failed to fetch repository '%s'", url)
             return
 
         if is_remote_ref:
@@ -485,7 +493,7 @@ class GitSync(BaseSync):
             try:
                 process = self.cmd.checkout(branch=git_tag)
             except exc.CommandError:
-                self.log.exception(f"Failed to checkout tag: '{git_tag}'")
+                self.log.exception("Failed to checkout tag: '%s'", git_tag)
                 return
 
             # Rebase changes from the remote branch
@@ -520,8 +528,8 @@ class GitSync(BaseSync):
                         self.cmd.stash.pop(index=True, quiet=True)
                         self.log.exception(
                             f"\nFailed to rebase in: '{self.path}'.\n"
-                            + "You will have to resolve the "
-                            + "conflicts manually",
+                            "You will have to resolve the "
+                            "conflicts manually",
                         )
                         return
 
@@ -529,7 +537,7 @@ class GitSync(BaseSync):
             try:
                 process = self.cmd.checkout(branch=git_tag)
             except exc.CommandError:
-                self.log.exception(f"Failed to checkout tag: '{git_tag}'")
+                self.log.exception("Failed to checkout tag: '%s'", git_tag)
                 return
 
         self.cmd.submodule.update(recursive=True, init=True, log_in_real_time=True)
@@ -557,7 +565,7 @@ class GitSync(BaseSync):
                 remotes[remote_name] = remote
         return remotes
 
-    def remote(self, name: str, **kwargs: Any) -> Optional[GitRemote]:
+    def remote(self, name: str, **kwargs: t.Any) -> GitRemote | None:
         """Get the fetch and push URL for a specified remote name.
 
         Parameters
